@@ -1,15 +1,16 @@
 package Text::MacroScript ; # Documented at the __END__.
 
-require 5.004 ;
+require 5.008;
 
-use strict ;
+use strict;
+use warnings;
 
 use Carp qw( carp croak ) ;
-use Cwd ;
+use Path::Tiny;
 use Symbol () ;
 
 use vars qw( $VERSION ) ;
-$VERSION = '2.02_02'; 
+$VERSION = '2.02_03'; 
 
 
 ### Object fields
@@ -270,7 +271,7 @@ sub list { # Object method.
 
     if( $which eq 'VARIABLE' ) {
         $array = [ map { [ $_, $self->{VARIABLE}{$_} ] } 
-                    keys %{$self->{VARIABLE}} ] ;
+                    sort keys %{$self->{VARIABLE}} ] ;
     }
     else {
         $array = $self->{$which} ;
